package app.sample.mbean;

import java.util.concurrent.atomic.AtomicInteger;

public class SampleCounter implements SampleCounterMXBean {

	private static SampleCounter instance = new SampleCounter();

	private AtomicInteger countSessions = new AtomicInteger(0);
	private AtomicInteger succeeded = new AtomicInteger(0);
	private AtomicInteger failured = new AtomicInteger(0);
	private AccessInfo lastAccessInfo;

	public static SampleCounter getInstance() {
		return instance;
	}

	public int sessionCreated() {
		return countSessions.incrementAndGet();
	}

	public int sessionDestroyed() {
		return countSessions.decrementAndGet();
	}

	public int success() {
		return succeeded.incrementAndGet();
	}

	public int failure() {
		return failured.incrementAndGet();
	}

	public void setLastAccessInfo(AccessInfo info) {
		this.lastAccessInfo = info;
	}

	@Override
	public int getCountSessions() {
		return countSessions.get();
	}

	@Override
	public String getName() {
		return "SampleCounter";
	}

	@Override
	public int getSucceededCount() {
		return succeeded.get();
	}

	@Override
	public int getFailuredCount() {
		return failured.get();
	}

	@Override
	public AccessInfo getLastAccessInfo() {
		return lastAccessInfo;
	}
}
