package app.sample;

import java.util.LinkedHashMap;
import java.util.Map.Entry;

public class CacheSample {


	private static final int INITIAL_CAPACITY = 5;
	private static final int MAX_ENTRIES = 5;

	static class FixedLRUCache extends LinkedHashMap<String, Object> {

		int cacheHit = 0;
		int getTotal = 0;

		public FixedLRUCache() {
			super(INITIAL_CAPACITY, 0.75f, true); // 第３引数をfalseにするとFIFOキャッシュになる
		}

		@Override
		protected boolean removeEldestEntry(Entry<String, Object> eldest) {
			return size() > MAX_ENTRIES;
		}

		@Override
		public Object get(Object key) {
			if (containsKey(key)) {
				cacheHit++;
			}
			getTotal++;
			return super.get(key);
		}

		public float getCacheHitRate() {
			if (getTotal == 0) {
				return 0f;
			}
			return (float) cacheHit / getTotal;
		}
	}


	public static void main(String[] args) {
		FixedLRUCache cache = new FixedLRUCache();
		cache.put("a", "1");
		cache.put("b", "2");
		cache.put("c", "3");
		cache.put("d", "4");
		cache.put("e", "5");

		cache.get("a"); // キーaにアクセスすると順番が変わる
		cache.get("g");
		cache.get("h");
		cache.put("f", "6"); // 容量を超えるので削除が行われる

		for (Object val : cache.values()) {
			System.out.println(val);
		}

		System.out.println(cache.getCacheHitRate());
	}
}
